@@ -404,7 +404,7 @@ class RedisClient(AbstractClient):
 
 
     def DeleteReplicationInstance(self, request):
-        """移除复制组成员
+        """移除复制组成员 注：接口下线中，请使用 RemoveReplicationInstance
 
         :param request: Request instance for DeleteReplicationInstance.
         :type request: :class:`tencentcloud.redis.v20180412.models.DeleteReplicationInstanceRequest`
